
Changelog
=========

0.0.1 (2021-10-06)
------------------

* First release on PyPI.


0.0.4 (2021-10-31)
------------------

* Seperated the storage module
* Added MongoDb storage class
* Started with documentation

